@@ -55,7 +55,8 @@ impl PolarError {
                 | ParseError::ExtraToken { loc, .. }
                 | ParseError::WrongValueType { loc, .. }
                 | ParseError::ReservedWord { loc, .. }
-                | ParseError::DuplicateKey { loc, .. } => {
+                | ParseError::DuplicateKey { loc, .. }
+                | ParseError::SingletonVariable { loc, .. } => {
                     let (row, column) = crate::lexer::loc_to_pos(&source.src, *loc);
                     self.context.replace(ErrorContext {
                         source: source.clone(),
@@ -187,6 +188,10 @@ pub enum ParseError {
         loc: usize,
         key: String,
     },
+    SingletonVariable {
+        loc: usize,
+        name: String,
+    },
 }
 
 impl fmt::Display for ErrorContext {
@@ -242,6 +247,13 @@ impl fmt::Display for ParseError {
             Self::DuplicateKey { key, .. } => {
                 write!(f, "Duplicate key: {}", key)
             }
+            Self::SingletonVariable { name, .. } => {
+                write!(
+                    f,
+                    "Singleton variable {} is unused or undefined; try renaming to _{} or _",
+                    name, name
+                )
+            }
         }
     }
 }
