@@ -1369,28 +1369,19 @@ fn test_anonymous_vars() {
 }
 
 #[test]
-fn test_singleton_vars() -> TestResult {
+fn test_singleton_vars() {
+    qparse!("f(x,y,z) if y = z;", ParseError::SingletonVariable { .. });
+}
+
+#[test]
+fn test_unknown_specializer_warning() -> TestResult {
     let p = Polar::new();
-    p.register_constant(sym!("X"), term!(true));
-    p.register_constant(sym!("Y"), term!(true));
-    p.load_str("f(x:X,y:Y,z:Z) if z = z;")?;
-    let output = p.next_message().unwrap();
-    assert!(matches!(&output.kind, MessageKind::Warning));
+    p.load_str("f(_: A);")?;
+    let out = p.next_message().unwrap();
+    assert!(matches!(&out.kind, MessageKind::Warning));
     assert_eq!(
-        &output.msg,
-        "Singleton variable x is unused or undefined, see <https://docs.osohq.com/using/polar-syntax.html#variables>\n001: f(x:X,y:Y,z:Z) if z = z;\n       ^"
-    );
-    let output = p.next_message().unwrap();
-    assert!(matches!(&output.kind, MessageKind::Warning));
-    assert_eq!(
-        &output.msg,
-        "Singleton variable y is unused or undefined, see <https://docs.osohq.com/using/polar-syntax.html#variables>\n001: f(x:X,y:Y,z:Z) if z = z;\n           ^"
-    );
-    let output = p.next_message().unwrap();
-    assert!(matches!(&output.kind, MessageKind::Warning));
-    assert_eq!(
-        &output.msg,
-        "Unknown specializer Z\n001: f(x:X,y:Y,z:Z) if z = z;\n                 ^"
+        &out.msg,
+        "Unknown specializer A\n001: f(_: A);\n          ^"
     );
     Ok(())
 }
